@@ -1,16 +1,9 @@
-#define C99 (__STDC_VERSION__ >= 199901L)
-#if !C99
-#if __GNUC__ < 2 || __GNUC__ == 2 && __GNUC_MINOR__ < 95
-#error Either a C99 compiler, or gcc 2.95.* or higher is required.
-#endif
+#ifdef HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <curses.h>
 
-#if !C99
-#define inline __inline
-#endif
-
 enum win { Top, Left, List, Input, Scrollbar, Right, Bottom, wCount };
 struct window {
 	WINDOW *win;
@@ -37,6 +30,7 @@ extern int maineventloop(
 	void(*drawitem)(struct item *item, bool highlight),
 	struct item *items,
 	const struct key *keys);
+extern void drawitems(void);
 extern void scrollcurrent(void);
 extern bool yesno(const char *);
 
@@ -45,6 +39,8 @@ static inline int wTop   (enum win w) { return (window[w].top   >= 0 ? 0 : LINES
 static inline int wLeft  (enum win w) { return (window[w].left  >= 0 ? 0 : COLS ) + window[w].left  ; }
 static inline int wHeight(enum win w) { return (window[w].height > 0 ? 0 : LINES) + window[w].height; }
 static inline int wWidth (enum win w) { return (window[w].width  > 0 ? 0 : COLS ) + window[w].width ; }
+static inline int min(int a, int b) { return a < b ? a : b; }
+static inline int max(int a, int b) { return a > b ? a : b; }
 
-extern int minheight, minwidth;
+extern int minwidth;
 extern int topy;
